==> jc-1.4.0.tar.gz: polyglot/lex/Keyword.h <==
// public class polyglot.lex.Keyword

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2ea531511a81498b polyglot_lex_Keyword
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_Keyword_H_
#define _JC_polyglot_lex_Keyword_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Keyword$sub_refs	_jc_polyglot_lex_Keyword$sub_refs;
typedef struct _jc_polyglot_lex_Keyword$sub_nonrefs	_jc_polyglot_lex_Keyword$sub_nonrefs;
typedef struct _jc_polyglot_lex_Keyword$refs	_jc_polyglot_lex_Keyword$refs;
typedef struct _jc_polyglot_lex_Keyword$nonrefs	_jc_polyglot_lex_Keyword$nonrefs;
typedef struct _jc_polyglot_lex_Keyword$object	_jc_polyglot_lex_Keyword$object;

typedef const struct _jc_polyglot_lex_Keyword$vmethods	_jc_polyglot_lex_Keyword$vmethods;
typedef const struct _jc_polyglot_lex_Keyword$vtable	_jc_polyglot_lex_Keyword$vtable;
typedef const struct _jc_polyglot_lex_Keyword$vtype	_jc_polyglot_lex_Keyword$vtype;

// Constructors
extern void _jc_polyglot_lex_Keyword$method$_init$37e74d0be0d3e539(_jc_env *, struct _jc_polyglot_lex_Keyword$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_Keyword$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_Keyword$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_Keyword$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_Keyword$object *);
};

// Vtable
struct _jc_polyglot_lex_Keyword$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Keyword$vmethods	polyglot_lex_Keyword;
};

// Vtype
struct _jc_polyglot_lex_Keyword$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Keyword$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Keyword$sub_refs {
	struct _jc_java_lang_String$object	*keyword;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Keyword$refs {
    _jc_polyglot_lex_Keyword$sub_refs	polyglot_lex_Keyword;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Keyword$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Keyword$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Keyword$sub_nonrefs	polyglot_lex_Keyword;
};

// Object instance structure
struct _jc_polyglot_lex_Keyword$object {
	_jc_polyglot_lex_Keyword$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Keyword$vtype	*vtype;
	_jc_polyglot_lex_Keyword$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Keyword$vtype _jc_polyglot_lex_Keyword$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Keyword, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Keyword$class_object;

#endif	/* _JC_polyglot_lex_Keyword_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/Keyword.h <==
// public class polyglot.lex.Keyword

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ea531511a81498b polyglot_lex_Keyword
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_Keyword_H_
#define _JC_polyglot_lex_Keyword_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Keyword$sub_refs	_jc_polyglot_lex_Keyword$sub_refs;
typedef struct _jc_polyglot_lex_Keyword$sub_nonrefs	_jc_polyglot_lex_Keyword$sub_nonrefs;
typedef struct _jc_polyglot_lex_Keyword$refs	_jc_polyglot_lex_Keyword$refs;
typedef struct _jc_polyglot_lex_Keyword$nonrefs	_jc_polyglot_lex_Keyword$nonrefs;
typedef struct _jc_polyglot_lex_Keyword$object	_jc_polyglot_lex_Keyword$object;

typedef const struct _jc_polyglot_lex_Keyword$vmethods	_jc_polyglot_lex_Keyword$vmethods;
typedef const struct _jc_polyglot_lex_Keyword$vtable	_jc_polyglot_lex_Keyword$vtable;
typedef const struct _jc_polyglot_lex_Keyword$vtype	_jc_polyglot_lex_Keyword$vtype;

// Constructors
extern void _jc_polyglot_lex_Keyword$method$_init$37e74d0be0d3e539(_jc_env *, struct _jc_polyglot_lex_Keyword$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_Keyword$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_Keyword$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_Keyword$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_Keyword$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_Keyword$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_Keyword$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Keyword$vmethods	polyglot_lex_Keyword;
};

// Vtype
struct _jc_polyglot_lex_Keyword$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Keyword$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Keyword$sub_refs {
	struct _jc_java_lang_String$object	*keyword;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Keyword$refs {
    _jc_polyglot_lex_Keyword$sub_refs	polyglot_lex_Keyword;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Keyword$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Keyword$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Keyword$sub_nonrefs	polyglot_lex_Keyword;
};

// Object instance structure
struct _jc_polyglot_lex_Keyword$object {
	_jc_polyglot_lex_Keyword$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Keyword$vtype	*vtype;
	_jc_polyglot_lex_Keyword$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Keyword$vtype _jc_polyglot_lex_Keyword$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Keyword, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Keyword$class_object;

#endif	/* _JC_polyglot_lex_Keyword_H_ */
